==> react-image-upload-grid-1.1.3.tgz: package/es/components/DropZoneHero.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';

// NPM Modules
import { StyleSheet, css } from 'aphrodite';
import Dropzone from 'react-dropzone';
import { faPlus } from '@fortawesome/free-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

var DropZoneHero = function (_Component) {
  _inherits(DropZoneHero, _Component);

  function DropZoneHero(props) {
    _classCallCheck(this, DropZoneHero);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.handleDrop = function (e) {
      e.preventDefault();
      e.persist();
      var files = e.dataTransfer.files;
      var src = window.URL.createObjectURL(files[0]);
      _this.setState({ showImage: true }, function () {
        _this.displayPreview(e, src);
        _this.props.appendFile(files);
      });
    };

    _this.displayPreview = function (e, src) {
      _this.setState({ showImage: true }, function () {
        var img = document.getElementById('image.' + e.target.id);
        img.src = src;
      });
    };

    _this.handleMouseOver = function (e) {
      _this.setState({
        showButton: true
      });
    };

    _this.handleMouseLeave = function (e) {
      _this.setState({
        showButton: false
      });
    };

    _this.handleClick = function (uid) {
      _this.props.removeFile(uid);
    };

    _this.onDrop = function (acceptedFiles) {
      _this.props.appendFile(acceptedFiles);
      acceptedFiles.forEach(function (file, index) {
        var blob = URL.createObjectURL(file);
        var uid = file.name + file.lastModified;
        _this.props.saveBlob({ uid: uid, blob: blob });
      });
    };

    _this.state = {
      showImage: false,
      showButton: false
    };
    return _this;
  }

  /**
   * Allows user to add image that are dragged on top of button 
   * @param { Event } e -- allows data from image to be saved onDrop
   * @function { displayPreviw } -- allows the image preview to be shown on the component
   * @function { appendFile } -- function on parent that adds the file to cache and to image array
   */


  /**
   * Reveals button that allows user to delete image
   * @param { Event } e -- triggered by MouseOver event
   */


  /**
   * Hides button that allows user to delete image
   * @param { Event } e -- triggered by MouseLeave event
   */


  /**
   * Allows user to delete image
   * @param { String } uid -- unique id passed by IIFE triggered onClick
   */


  /**
   * When files are uploaded
   * @param { Object } acceptedFiles -- the files we've accepted
   */


  DropZoneHero.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        id = _props.id,
        images = _props.images;


    return React.createElement(
      Dropzone,
      {
        onDrop: this.onDrop,
        className: css(styles.DropZoneGrid) },
      function (_ref) {
        var getRootProps = _ref.getRootProps,
            getInputProps = _ref.getInputProps;

        return React.createElement(
          'div',
          _extends({
            className: css(styles.DropZoneHero) + ' ' + _this2.props.addImageClassName
          }, getRootProps()),
          React.createElement('input', _extends({}, getInputProps(), { accept: _this2.props.fileAccept })),
          _this2.props.addImageText ? _this2.props.addImageText : React.createElement(FontAwesomeIcon, { icon: faPlus, size: '2x' })
        );
      }
    );
  };

  return DropZoneHero;
}(Component);

export { DropZoneHero as default };


var styles = StyleSheet.create({
  DropZoneHero: {
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    width: 180,
    height: 180,
    overflow: "hidden",
    margin: 10,
    outline: 'none',
    fontFamily: "Helvetica",
    color: "black",
    lineHeight: 1.5,
    textAlign: "center",
    alignItems: 'center',
    cursor: "pointer",
    border: "2px dashed #ccc",
    ":hover": {
      border: "2px dashed black"
    }
  },
  preview: {
    objectFit: "contain",
    width: "auto",
    height: "auto",
    float: "left",
    overflow: "hidden"
  },
  CloseButton: {
    position: "absolute",
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    alignItems: "center",
    zIndex: 100,
    top: 1,
    right: 0.5,
    height: 25,
    width: 25,
    borderRadius: "50%",
    color: "white",
    background: "rgba(255, 0, 0)",
    boxShadow: 'rgba(129,148,167,0.39) 0px 3px 20px 0px',
    transition: "all 0.2s ease-in-out",
    opacity: 0.8,
    ":hover": {
      opacity: 1
    }
  },
  ButtonText: {
    margin: 0,
    paddingBottom: 2
  }
});

==> react-image-upload-grid-1.1.4.tgz: package/es/components/DropZoneHero.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';

// NPM Modules
import { StyleSheet, css } from 'aphrodite';
import Dropzone from 'react-dropzone';
import { faPlus } from '@fortawesome/free-solid-svg-icons/faPlus';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

var DropZoneHero = function (_Component) {
  _inherits(DropZoneHero, _Component);

  function DropZoneHero(props) {
    _classCallCheck(this, DropZoneHero);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.handleDrop = function (e) {
      e.preventDefault();
      e.persist();
      var files = e.dataTransfer.files;
      var src = window.URL.createObjectURL(files[0]);
      _this.setState({ showImage: true }, function () {
        _this.displayPreview(e, src);
        _this.props.appendFile(files);
      });
    };

    _this.displayPreview = function (e, src) {
      _this.setState({ showImage: true }, function () {
        var img = document.getElementById('image.' + e.target.id);
        img.src = src;
      });
    };

    _this.handleMouseOver = function (e) {
      _this.setState({
        showButton: true
      });
    };

    _this.handleMouseLeave = function (e) {
      _this.setState({
        showButton: false
      });
    };

    _this.handleClick = function (uid) {
      _this.props.removeFile(uid);
    };

    _this.onDrop = function (acceptedFiles) {
      _this.props.appendFile(acceptedFiles);
      acceptedFiles.forEach(function (file, index) {
        var blob = URL.createObjectURL(file);
        var uid = file.name + file.lastModified;
        _this.props.saveBlob({ uid: uid, blob: blob });
      });
    };

    _this.state = {
      showImage: false,
      showButton: false
    };
    return _this;
  }

  /**
   * Allows user to add image that are dragged on top of button 
   * @param { Event } e -- allows data from image to be saved onDrop
   * @function { displayPreviw } -- allows the image preview to be shown on the component
   * @function { appendFile } -- function on parent that adds the file to cache and to image array
   */


  /**
   * Reveals button that allows user to delete image
   * @param { Event } e -- triggered by MouseOver event
   */


  /**
   * Hides button that allows user to delete image
   * @param { Event } e -- triggered by MouseLeave event
   */


  /**
   * Allows user to delete image
   * @param { String } uid -- unique id passed by IIFE triggered onClick
   */


  /**
   * When files are uploaded
   * @param { Object } acceptedFiles -- the files we've accepted
   */


  DropZoneHero.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        id = _props.id,
        images = _props.images;


    return React.createElement(
      Dropzone,
      {
        onDrop: this.onDrop,
        className: css(styles.DropZoneGrid) },
      function (_ref) {
        var getRootProps = _ref.getRootProps,
            getInputProps = _ref.getInputProps;

        return React.createElement(
          'div',
          _extends({
            className: css(styles.DropZoneHero) + ' ' + _this2.props.addImageClassName
          }, getRootProps()),
          React.createElement('input', _extends({}, getInputProps(), { accept: _this2.props.fileAccept })),
          _this2.props.addImageText ? _this2.props.addImageText : React.createElement(FontAwesomeIcon, { icon: faPlus, size: '2x' })
        );
      }
    );
  };

  return DropZoneHero;
}(Component);

export { DropZoneHero as default };


var styles = StyleSheet.create({
  DropZoneHero: {
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    width: 180,
    height: 180,
    overflow: "hidden",
    margin: 10,
    outline: 'none',
    fontFamily: "Helvetica",
    color: "black",
    lineHeight: 1.5,
    textAlign: "center",
    alignItems: 'center',
    cursor: "pointer",
    border: "2px dashed #ccc",
    ":hover": {
      border: "2px dashed black"
    }
  },
  preview: {
    objectFit: "contain",
    width: "auto",
    height: "auto",
    float: "left",
    overflow: "hidden"
  },
  CloseButton: {
    position: "absolute",
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    alignItems: "center",
    zIndex: 100,
    top: 1,
    right: 0.5,
    height: 25,
    width: 25,
    borderRadius: "50%",
    color: "white",
    background: "rgba(255, 0, 0)",
    boxShadow: 'rgba(129,148,167,0.39) 0px 3px 20px 0px',
    transition: "all 0.2s ease-in-out",
    opacity: 0.8,
    ":hover": {
      opacity: 1
    }
  },
  ButtonText: {
    margin: 0,
    paddingBottom: 2
  }
});
